@@ -3,28 +3,34 @@ from deezer.pagination import PaginatedList
 from deezer.resources import (
     Album,
     Artist,
+    Chart,
     Editorial,
+    Episode,
     Genre,
     Playlist,
+    Podcast,
     Radio,
     Resource,
     Track,
     User,
 )
 
-__version__ = "5.3.0"
+__version__ = "5.3.2"
 __all__ = [
-    "Client",
-    "PaginatedList",
-    "Resource",
     "Album",
     "Artist",
+    "Chart",
+    "Client",
     "Editorial",
+    "Episode",
     "Genre",
+    "PaginatedList",
     "Playlist",
+    "Podcast",
+    "Radio",
+    "Resource",
     "Track",
     "User",
-    "Radio",
 ]
 
 USER_AGENT = f"Deezer Python API Wrapper v{__version__}"
